<?php

namespace Thaolx\TrialPackage\Http\Controllers;
use Litepie\TrialPackage\Http\Requests\TrialpackageRequest;
use Litepie\TrialPackage\Models\Trialpackage;

trait TrialpackageWorkflow {
	
    /**
     * Workflow controller function for trialpackage.
     *
     * @param Model   $trialpackage
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TrialpackageRequest $request, Trialpackage $trialpackage, $step)
    {

        try {

            $trialpackage->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('trial_package::trialpackage.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/trialpackage/trialpackage/' . $trialpackage->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/trialpackage/trialpackage/' . $trialpackage->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for trialpackage.
     *
     * @param Model   $trialpackage
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Trialpackage $trialpackage, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $trialpackage->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('trial_package::trialpackage.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('trial_package::admin.trialpackage.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('trial_package::admin.trialpackage.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('trial_package::admin.trialpackage.message', $data)->render();

        }

    }
}